INSTALLED_APPS = (
    'oauth_tokens',
    'taggit',
    'vkontakte_api',
    'vkontakte_places',
    'vkontakte_users',
    'vkontakte_groups',
    'vkontakte_wall',
    'm2m_history',
)

OAUTH_TOKENS_VKONTAKTE_CLIENT_ID = 3430034
OAUTH_TOKENS_VKONTAKTE_CLIENT_SECRET = 'b0FwzyKtO8QiQmgWQMTz'
OAUTH_TOKENS_VKONTAKTE_SCOPE = ['ads,wall,photos,friends,stats']
OAUTH_TOKENS_VKONTAKTE_USERNAME = '+919665223715'
OAUTH_TOKENS_VKONTAKTE_PASSWORD = 'githubovich'
OAUTH_TOKENS_VKONTAKTE_PHONE_END = '3715'